@@ -24,6 +24,13 @@ def mainmenu(parent):
     loadNWB.triggered.connect(lambda: io.load_dialog_NWB(parent))
     parent.addAction(loadNWB)
 
+    # load folder of processed data
+    loadFolder = QtGui.QAction("Load &Folder with planeX folders", parent)
+    loadFolder.setShortcut("Ctrl+F")
+    loadFolder.triggered.connect(lambda: io.load_dialog_folder(parent))
+    parent.addAction(loadFolder)
+
+
     # load a behavioral trace
     parent.loadBeh = QtGui.QAction(
         "Load behavior or stim trace (1D only)", parent
@@ -57,6 +64,7 @@ def mainmenu(parent):
     file_menu.addAction(runS2P)
     file_menu.addAction(loadProc)
     file_menu.addAction(loadNWB)
+    file_menu.addAction(loadFolder)
     file_menu.addAction(parent.loadBeh)
     file_menu.addAction(parent.saveMat)
     file_menu.addAction(exportFig)
